package com.hfkj.service.item.impl;

import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.utils.MD5Util;
import com.hfkj.dao.EnTransportCompanyCarMapper;
import com.hfkj.entity.*;
import com.hfkj.service.SecUserService;
import com.hfkj.service.item.EnTransportCompanyCarService;
import com.hfkj.sysenum.SecUserObjectTypeEnum;
import com.hfkj.sysenum.SecUserStatusEnum;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.Map;


@Service("enTransportCompanyCarService")
public class EnTransportCompanyCarServiceImpl implements EnTransportCompanyCarService {

    @Resource
    private EnTransportCompanyCarMapper enTransportCompanyCarMapper;
    @Resource
    private SecUserService secUserService;

    @Override
    public void create(EnTransportCompanyCar enTransportCompanyCar) throws Exception {
        enTransportCompanyCarMapper.insert(enTransportCompanyCar);

        if (secUserService.getDetailByLoginName(enTransportCompanyCar.getContactInfo()) != null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "登录账户已存在，请更换");
        }

        SecUser secUser = new SecUser();
        secUser.setUserName(enTransportCompanyCar.getPerson());
        secUser.setLoginName(enTransportCompanyCar.getContactInfo());
        secUser.setPassword(MD5Util.encode("123456".getBytes()));
        secUser.setTelephone(enTransportCompanyCar.getContactInfo());
        secUser.setRoleId(1029L);
        secUser.setObjectType(SecUserObjectTypeEnum.type6.getCode());
        secUser.setObjectId(enTransportCompanyCar.getId());
        secUser.setStatus(SecUserStatusEnum.status1.getCode());
        secUserService.editUser(secUser);
    }

    @Override
    public void update(EnTransportCompanyCar enTransportCompanyCar) {
        enTransportCompanyCarMapper.updateByPrimaryKey(enTransportCompanyCar);
        // 查询账户
        SecUser secUser = secUserService.getDetail(SecUserObjectTypeEnum.type6, enTransportCompanyCar.getId());
        if (secUser == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "账户数据异常");
        }
        secUser.setUserName(enTransportCompanyCar.getPerson());
        secUserService.editUser(secUser);
    }

    @Override
    public void delete(Long id, Boolean fullDelete) {
        EnTransportCompanyCar enTransportCompanyCar = queryDetail(id);
        if (fullDelete) {
            enTransportCompanyCarMapper.deleteByPrimaryKey(id);
        } else {

            enTransportCompanyCar.setStatus(0);
            enTransportCompanyCar.setUpdateTime(new Date());
            update(enTransportCompanyCar);
        }

        // 查询账户
        SecUser secUser = secUserService.getDetail(SecUserObjectTypeEnum.type6, enTransportCompanyCar.getId());
        if (secUser == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "账户数据异常");
        }
        secUser.setStatus(SecUserStatusEnum.status0.getCode());
        secUserService.editUser(secUser);
    }

    @Override
    public EnTransportCompanyCar queryDetail(Long id) {
        return enTransportCompanyCarMapper.selectByPrimaryKey(id);
    }

    @Override
    public EnTransportCompanyCar queryDetailByMap(Map<String, Object> map) {
        EnTransportCompanyCarExample example = new EnTransportCompanyCarExample();
        EnTransportCompanyCarExample.Criteria criteria = example.createCriteria();

        if (StringUtils.isNotBlank(MapUtils.getString(map, "person"))) {
            criteria.andPersonLike("%"+MapUtils.getString(map, "person")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "carNo"))) {
            criteria.andPersonLike("%"+MapUtils.getString(map, "carNo")+"%");
        }
        if (MapUtils.getLong(map, "createUser") != null) {
            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "createUser"));
        }
        if (MapUtils.getInteger(map, "carType") != null) {
            criteria.andCarTypeEqualTo(MapUtils.getInteger(map, "carType"));
        }

        if (MapUtils.getLong(map, "transportId") != null) {
            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "transportId"));
        }

        if (StringUtils.isNotBlank(MapUtils.getString(map, "person"))) {
            criteria.andPersonLike("%"+MapUtils.getString(map, "person")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactInfo"))) {
            criteria.andContactInfoLike("%"+MapUtils.getString(map, "contactInfo")+"%");
        }
        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        }else {
            criteria.andStatusNotEqualTo(0);
        }
        if (MapUtils.getLong(map , "id") != null) {
            criteria.andIdEqualTo(MapUtils.getLong(map , "id"));
        }
        List<EnTransportCompanyCar> list = enTransportCompanyCarMapper.selectByExample(example);

        return list.isEmpty() ? null : list.get(0);
    }

    @Override
    public List<EnTransportCompanyCar> getList(Map<String, Object> map) {
        EnTransportCompanyCarExample example = new EnTransportCompanyCarExample();
        EnTransportCompanyCarExample.Criteria criteria = example.createCriteria();

        if (StringUtils.isNotBlank(MapUtils.getString(map, "person"))) {
            criteria.andPersonLike("%"+MapUtils.getString(map, "person")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "carNo"))) {
            criteria.andPersonLike("%"+MapUtils.getString(map, "carNo")+"%");
        }
        if (MapUtils.getLong(map, "createUser") != null) {
            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "createUser"));
        }
        if (MapUtils.getInteger(map, "carType") != null) {
            criteria.andCarTypeEqualTo(MapUtils.getInteger(map, "carType"));
        }

        if (MapUtils.getLong(map, "transportId") != null) {
            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "transportId"));
        }

        if (StringUtils.isNotBlank(MapUtils.getString(map, "person"))) {
            criteria.andPersonLike("%"+MapUtils.getString(map, "person")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactInfo"))) {
            criteria.andContactInfoLike("%"+MapUtils.getString(map, "contactInfo")+"%");
        }
        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        }else {
            criteria.andStatusNotEqualTo(0);
        }
        if (MapUtils.getLong(map , "id") != null) {
            criteria.andIdEqualTo(MapUtils.getLong(map , "id"));
        }
        return enTransportCompanyCarMapper.selectByExample(example)  ;
    }
}
